﻿using System.Text.Json;
using Microsoft.Azure.Functions.Worker;
using Microsoft.OneFuzz.Service.OneFuzzLib.Orm;

namespace Microsoft.OneFuzz.Service.Functions;

public class QueueProxyHearbeat {
    private readonly ILogTracer _log;

    private readonly IProxyOperations _proxy;

    public QueueProxyHearbeat(ILogTracer log, IProxyOperations proxy) {
        _log = log;
        _proxy = proxy;
    }

    [Function("QueueProxyUpdate")]
    public async Async.Task Run([QueueTrigger("proxy", Connection = "AzureWebJobsStorage")] string msg) {
        _log.Info($"heartbeat: {msg}");

        var hb = JsonSerializer.Deserialize<ProxyHeartbeat>(msg, EntityConverter.GetJsonSerializerOptions()).EnsureNotNull($"wrong data {msg}"); ;
        var newHb = hb with { TimeStamp = DateTimeOffset.UtcNow };

        var proxy = await _proxy.GetByProxyId(newHb.ProxyId);

        if (proxy == null) {
            _log.Warning($"invalid proxy id: {newHb.ProxyId:Tag:ProxyId}");
            return;
        }
        var newProxy = proxy with { Heartbeat = newHb };

        var r = await _proxy.Replace(newProxy);
        if (!r.IsOk) {
            _log.WithHttpStatus(r.ErrorV).Error($"Failed to replace proxy heartbeat {newHb.ProxyId:Tag:ProxyId}");
        }
    }
}
